as_external_function_t

Function as_external_function_t 

pub unsafe extern "C" fn as_external_function_t(
    f: *mut c_void,
) -> external_function_t
@brief Cast an external function to \ref external_function_t

Some external functions may not use all the parameters (or may use the implicit 6th parameter) and, therefore, not match the \ref external_function_t typedef. Use this for a conversion.

@param[in] f The function to cast to match the signature of an external function. @retval The external function, as external_function_t.