pub unsafe extern "C" fn ubpf_set_jit_code_size(
vm: *mut ubpf_vm,
code_size: usize,
) -> c_intExpand description
@brief Set a size for the buffer allocated to machine code generated during JIT compilation. The JIT compiler allocates a buffer to store the code while it is being generated. The default may be too big for some embedded platforms. Use this to customize the size of that buffer. Note: The buffer being sized here is not the final location of the machine code returned by ubpf_compile – that buffer is perfectly sized to match the size of the generated machine code.
@param[in] vm The VM to set the buffer size for. @param[in] code_size The size of the buffer to use. @retval 0 Success. @retval -1 Failure.