ubpf_set_unwind_function_index

Function ubpf_set_unwind_function_index 

pub unsafe extern "C" fn ubpf_set_unwind_function_index(
    vm: *mut ubpf_vm,
    idx: c_uint,
) -> c_int
@brief Instruct the uBPF runtime to apply unwind-on-success semantics to a helper function. If the function returns 0, the uBPF runtime will end execution of the eBPF program and immediately return control to the caller. This is used for implementing function like the “bpf_tail_call” helper.

@param[in] vm The VM to set the unwind helper in. @param[in] idx Index of the helper function to unwind on success. @retval 0 Success. @retval -1 Failure.