ubpf_toggle_undefined_behavior_check

Function ubpf_toggle_undefined_behavior_check 

pub unsafe extern "C" fn ubpf_toggle_undefined_behavior_check(
    vm: *mut ubpf_vm,
    enable: bool,
) -> bool
@brief Enable or disable undefined behavior checks. Undefined behavior includes reading from uninitialized memory or using uninitialized registers. Default is disabled to preserve performance and compatibility with existing eBPF programs.

@param[in] vm VM to enable or disable undefined behavior checks on. @param[in] enable Enable undefined behavior checks if true, disable if false. @retval true Undefined behavior checks were previously enabled. @retval false Undefined behavior checks were previously disabled.