JitMode

Type Alias JitMode 

pub type JitMode = c_uint;
@brief Enum to describe JIT mode.

ExtendedJitMode specifies that an invocation of that code have 4 parameters:

  1. A pointer to the program’s memory space.
  2. The size of the program’s memory space.
  3. A pointer to memory to be used by the program as a stack during execution.
  4. The size of the provided stack space. See ubpf_jit_ex_fn for more information.

BasicJitMode specifies that an invocation of that code have 2 parameters:

  1. A pointer to the program’s memory space.
  2. The size of the program’s memory space. The function generated by the JITer executing in basic mode automatically allocates a stack for the program’s execution. See ubpf_jit_fn for more information.