pub type JitMode = c_uint;Expand description
@brief Enum to describe JIT mode.
ExtendedJitMode specifies that an invocation of that code have 4 parameters:
- A pointer to the program’s memory space.
- The size of the program’s memory space.
- A pointer to memory to be used by the program as a stack during execution.
- The size of the provided stack space. See ubpf_jit_ex_fn for more information.
BasicJitMode specifies that an invocation of that code have 2 parameters:
- A pointer to the program’s memory space.
- The size of the program’s memory space. The function generated by the JITer executing in basic mode automatically allocates a stack for the program’s execution. See ubpf_jit_fn for more information.