pub type external_function_t = Option<unsafe extern "C" fn(p0: u64, p1: u64, p2: u64, p3: u64, p4: u64) -> u64>;Expand description
@brief The type of an external helper function.
Note: There is an implicit void *-typed 6th parameter that users can access if they choose. That sixth parameter’s value is the value of the pointer given by the user of \ref ubpf_exec, \ref ubpf_exec_ex, and the function generated by \ref ubpf_translate as the first argument.
Aliased Type
pub enum external_function_t {
None,
Some(unsafe extern "C" fn(u64, u64, u64, u64, u64) -> u64),
}