pub type ubpf_data_relocation = Option<unsafe extern "C" fn(user_context: *mut c_void, data: *const u8, data_size: u64, symbol_name: *const c_char, symbol_offset: u64, symbol_size: u64) -> u64>;Expand description
@brief Data relocation function that is called by the VM when it encounters a R_BPF_64_64 relocation in the maps section of the ELF file.
@param[in] user_context The user context that was passed to ubpf_register_data_relocation. @param[in] data Pointer to start of the map section. @param[in] data_size Size of the map section. @param[in] symbol_name Name of the symbol that is referenced. @param[in] symbol_offset Offset of the symbol relative to the start of the map section. @param[in] symbol_size Size of the symbol. @return The value to insert into the BPF program.
Aliased Type
pub enum ubpf_data_relocation {
None,
Some(unsafe extern "C" fn(*mut c_void, *const u8, u64, *const i8, u64, u64) -> u64),
}